@@ -421,11 +421,9 @@ var GdeployUtil = {
             ]
         )
         .done(function(code) {
-            console.log("True")
             callBack(true)
         })
         .fail(function(code) {
-            console.log("false")
             callBack(false)
         })
     }
